pub enum TraversalDirection {
Outgoing,
Incoming,
Both,
}Expand description
Slice 20 (G5) — direction of graph traversal for
Engine::graph_neighbors / Engine::search_expand.
Outgoing follows edges where the root is the from_id (source).
Incoming follows edges where the root is the to_id (target).
Both follows edges in either direction.
Variants