pub struct ChunkInsert {
pub id: String,
pub node_logical_id: String,
pub text_content: String,
pub byte_start: Option<i64>,
pub byte_end: Option<i64>,
pub content_hash: Option<String>,
}Expand description
A text chunk to be inserted in a WriteRequest.
Fields
id: Stringnode_logical_id: Stringtext_content: Stringbyte_start: Option<i64>byte_end: Option<i64>content_hash: Option<String>Optional hash of the external content this chunk was derived from.