pub struct DrainReport {
pub incremental_processed: u64,
pub backfill_processed: u64,
pub failed: u64,
pub discarded_stale: u64,
pub embedder_unavailable_ticks: u64,
}Expand description
Report returned from AdminService::drain_vector_projection.
Fields
incremental_processed: u64Number of incremental (priority >= 1000) work rows that produced a vec row in this drain.
backfill_processed: u64Number of backfill (priority < 1000) work rows that produced a vec row in this drain.
failed: u64Number of rows that produced a hard failure (e.g. embedder output wrong dimension).
discarded_stale: u64Number of rows whose canonical_hash mismatched the current chunk
and were marked discarded.
Number of ticks that were aborted because the embedder was unavailable.