pub struct ProjectionService { /* private fields */ }Implementations
Sourceimpl ProjectionService
impl ProjectionService
pub fn new(path: impl AsRef<Path>, schema_manager: Arc<SchemaManager>) -> Self
Sourcepub fn rebuild_projections(
&self,
target: ProjectionTarget,
) -> Result<ProjectionRepairReport, EngineError>
pub fn rebuild_projections( &self, target: ProjectionTarget, ) -> Result<ProjectionRepairReport, EngineError>
Errors
Returns EngineError if the database connection fails or the projection rebuild fails.
Sourcepub fn rebuild_missing_projections(
&self,
) -> Result<ProjectionRepairReport, EngineError>
pub fn rebuild_missing_projections( &self, ) -> Result<ProjectionRepairReport, EngineError>
Errors
Returns EngineError if the database connection fails or the INSERT query fails.