pub struct RebuildReport {
pub kind: RebuildKind,
pub rows_invalidated: u64,
pub rows_rebuilt: u64,
pub projection_cursor_after: u64,
}Expand description
Structured result of a rebuild operation. rows_invalidated is the
total shadow-state rows truncated before re-derivation; rows_rebuilt
is the count of rows the synchronous rebuild loop re-materialised
(asynchronous re-enqueue work performed by the projection scheduler is
not counted here). projection_cursor_after is the post-rebuild value
of the projection cursor.
Fields
kind: RebuildKindrows_invalidated: u64rows_rebuilt: u64projection_cursor_after: u64Trait Implementations
Sourceimpl Clone for RebuildReport
impl Clone for RebuildReport
Sourcefn clone(&self) -> RebuildReport
fn clone(&self) -> RebuildReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RebuildReport
impl Debug for RebuildReport
Sourceimpl PartialEq for RebuildReport
impl PartialEq for RebuildReport
Sourcefn eq(&self, other: &RebuildReport) -> bool
fn eq(&self, other: &RebuildReport) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for RebuildReport
impl StructuralPartialEq for RebuildReport