SqliteCacheStatus

Struct SqliteCacheStatus 

pub struct SqliteCacheStatus {
    pub cache_hits: i64,
    pub cache_misses: i64,
    pub cache_writes: i64,
    pub cache_spills: i64,
}
Cumulative SQLite page-cache counters for a single connection.

Uses i64 to allow safe summing across pool connections without overflow.

Fields

cache_hits: i64

Page cache hits.

cache_misses: i64

Page cache misses.

cache_writes: i64

Pages written to cache.

cache_spills: i64

Cache pages spilled to disk.

Implementations

Source

impl SqliteCacheStatus

pub fn add(&mut self, other: &Self)

Add another status into this one (for aggregating across connections).

Uses saturating arithmetic to avoid panics on overflow in debug builds.